==> kdebase-1.1.2.tar.bz2: kdebase-1.1.2/kcontrol/input/keyboard.h <==
/*
 * keyboard.h
 *
 * Copyright (c) 1997 Patrick Dowler dowler@morgul.fsh.uvic.ca
 *
 * Requires the Qt widget libraries, available at no cost at
 * http://www.troll.no/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __KKEYBOARDCONFIG_H__
#define __KKEYBOARDCONFIG_H__

#include <qlabel.h>
#include <qradiobt.h>
#include <qbttngrp.h>
#include <qpushbt.h>
#include <qlcdnum.h>
#include <kapp.h>
#include <kslider.h>

#include <kcontrol.h>
#include "kslidercontrol.h"

class KeyboardConfig : public KConfigWidget
{
  Q_OBJECT
public:
  KeyboardConfig( QWidget *parent=0, const char* name=0, bool init=FALSE );
  ~KeyboardConfig( );
  void  resizeEvent(QResizeEvent *e);
  void saveParams( void );

  void loadSettings();
  void applySettings();
  void defaultSettings();
      
private:
  void GetSettings( void );

  void setClick( int );
  void setRepeat( int );
  void setRepeatRate( int );

  int getClick();
  int getRepeat();
  int getRepeatRate();

  QButtonGroup *repeatBox;
  QRadioButton *repeatOn, *repeatOff;

  KSliderControl *click;

  KConfig *config;
  int clickVolume, keyboardRepeat;
};

#endif

==> kdebase-1.90.tar.bz2: kdebase-1.90/kcontrol/input/keyboard.h <==
/*
 * keyboard.h
 *
 * Copyright (c) 1997 Patrick Dowler dowler@morgul.fsh.uvic.ca
 *
 * Requires the Qt widget libraries, available at no cost at
 * http://www.troll.no/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __KKEYBOARDCONFIG_H__
#define __KKEYBOARDCONFIG_H__


#include <kapp.h>
#include <kcmodule.h>


class KIntNumInput;
class KConfig;
class QCheckBox;


class KeyboardConfig : public KCModule
{
  Q_OBJECT
public:
  KeyboardConfig( QWidget *parent=0, const char* name=0);

  void save();
  void load();
  void defaults();

  QString quickHelp();

private slots:

  void changed();

      
private:

  void setClick( int );
  void setRepeat( int );
  void setRepeatRate( int );

  int getClick();
  int getRepeatRate();

  QCheckBox *repeatBox;
  KIntNumInput *click;

  int clickVolume, keyboardRepeat;
};

#endif
